@@ -57,7 +57,7 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
      * (w,h)の大きさのA3Canvasを作ります。
      */
     public static A3Canvas createA3Canvas(GraphicsConfiguration graCon,int w,int h) {
-        return new A3Canvas(graCon,w,h);
+         return new A3Canvas(graCon,w,h);
     }
 
     A3Canvas(GraphicsConfiguration graCon,int w,int h) {
@@ -1045,7 +1045,7 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
 
     @Override
     public void setNavigationMode(int scene,NaviMode m,Object...params) {
-        universe.setNavigationMode(m,scene,params);
+        universe.setNavigationMode(scene,m,params);
     }
 
     @Override
