@@ -3,7 +3,7 @@ package jp.sourceforge.acerola3d.sound;
 import javax.vecmath.*;
 
 public interface A3Sound {
-    public void init(String url,A3SoundSystem ss,float segno,A3SoundType type,float gain,boolean loop) throws Exception;
+    public void init(String url,A3SoundSystem ss,float segno,A3SoundType type,float gain,boolean loop,Vector3d offset,Vector3d dir) throws Exception;
     public void start();//resumeとしても働く
     public void segno();
     public void stop();
@@ -17,8 +17,10 @@ public interface A3Sound {
     public void setVel();
     public void setGain(float g);
     public float getGain();
-    public void setDirection(float x,float y,float z);
-    public void setDirection(Vector3d d);
+    public void setDirection(float x,float y,float z);//内部座標における値
+    public void setDirection(Vector3d d);//内部座標における値
+    public void setOffset(float x,float y,float z);
+    public void setOffset(Vector3d o);
     public void setLoop(boolean l);
     public void cleanUp();
     public A3Sound copy();
